@@ -1,8 +1,12 @@
-version = (0, 2, 2)
+"""django-sslify package information."""
+
+
+VERSION = (0, 2, 4)
 
 
 def get_version():
     """returns a pep compliant version number"""
-    return '.'.join(str(i) for i in version)
+    return '.'.join(str(i) for i in VERSION)
+
 
 __version__ = get_version()
