@@ -1,11 +1,21 @@
+"""Tests."""
+
+
+try:
+    # Python 2.x
+    from urlparse import urlsplit
+except ImportError:
+    # Python 3.x
+    from urllib.parse import urlsplit
+
 from django.http import HttpResponsePermanentRedirect
 from django.test import TestCase
 from django.test.client import RequestFactory
 
-from sslify.middleware import SSLifyMiddleware as _SSLifyMiddleware
+from sslify.middleware import SSLifyMiddleware
 
 
-class SSLifyMiddlware(TestCase):
+class SSLifyMiddlwareTest(TestCase):
 
     def setUp(self):
         self.factory = RequestFactory()
@@ -14,14 +24,23 @@ class SSLifyMiddlware(TestCase):
         request = self.factory.get('/woot/')
         self.assertTrue(request.build_absolute_uri().startswith('http://'))
 
-        middleware = _SSLifyMiddleware()
+        middleware = SSLifyMiddleware()
         request = middleware.process_request(request)
 
         self.assertIsInstance(request, HttpResponsePermanentRedirect)
         self.assertTrue(request['Location'].startswith('https://'))
+        self.assertEqual(443, urlsplit(request['Location']).port)
+
+    def test_custom_ssl_port(self):
+        custom_port = 8443
+        with self.settings(SSLIFY_PORT=custom_port):
+            request = self.factory.get('/woot/')
+            middleware = SSLifyMiddleware()
+            request = middleware.process_request(request)
+
+            self.assertEqual(custom_port, urlsplit(request['Location']).port)
 
     def test_disable_for_tests(self):
-        """If disabled, we get a 404"""
         with self.settings(SSLIFY_DISABLE=True):
             request = self.client.get('/woot/')
             self.assertEqual(404, request.status_code)
